PlasmaPy v2023.5.1 (2023-06-07)
===============================

Trivial/Internal Changes
------------------------

- Loosened the requirement on ``ipykernel`` for compatibility with
  Google Colab. (:pr:`2202`)
